@@ -127,7 +127,7 @@ export default class MsgList extends React.Component {
   componentDidMount() {
     // load first messages
     var start = Date.now()
-    this.loadMore({ amt: this.props.DEFAULT_BATCH_LOAD_AMT }, () => console.log(Date.now() - start))
+    this.loadMore({ amt: DEFAULT_BATCH_LOAD_AMT }, () => console.log(Date.now() - start))
 
     // setup autoresizing
     this.calcContainerHeight()
@@ -365,7 +365,7 @@ export default class MsgList extends React.Component {
           isInfiniteLoading={this.state.isLoading}>
           <div className="flex">
             { LeftNav ? <LeftNav {...this.props.leftNavProps} /> : '' }
-            <div className="flex-fill">
+            <div className="flex-fill" style={{padding: '5px'}}>
               { Hero ? <Hero/> : '' }
               { nQueued ?
                 <a className="new-msg-queue" onClick={this.reload.bind(this)}>{nQueued} new update{u.plural(nQueued)}</a>
@@ -399,7 +399,7 @@ export default class MsgList extends React.Component {
                       lastDate = moment(lastPost.value.timestamp)
                       if (this.props.dateDividers && !lastDate.isSame(oldLastDate, 'day')) {
                         let label = (lastDate.isSame(endOfToday, 'day')) ? 'today' : lastDate.endOf('day').from(endOfToday)
-                        return <div key={m.key}><hr className="labeled" data-label={label} />{item}</div>
+                        return <div key={m.key} className="divider-spot"><hr className="labeled" data-label={label} />{item}</div>
                       }
                       return item
                     }) }
